@@ -141,16 +141,34 @@ class VersionClassBase(object):
     def reify(self, visited_objects=[]):
         if self in visited_objects:
             return
+
+        if self.operation_type == 2:
+            print "jep"
+            session = sa.orm.object_session(self)
+            session.delete(self.parent)
+            return
+
         visited_objects.append(self)
         parent_mapper = self.__parent_class__.__mapper__
 
         # Check if parent object has been deleted
         if self.parent is None:
             self.parent = self.__parent_class__()
+            session = sa.orm.object_session(self)
+            session.add(self.parent)
+
+        # Before reifying relations we need to reify object properties. This
+        # is needed because reifying relations might need to flush the session
+        # which leads to errors when sqlalchemy tries to insert null values
+        # into parent object (if parent object has not null constraints).
+        for key, attr in parent_mapper.class_manager.items():
+            if isinstance(attr.property, sa.orm.ColumnProperty):
+                if key != 'transaction_id':
+                    setattr(self.parent, key, getattr(self, key))
 
         for key, attr in parent_mapper.class_manager.items():
-            if key not in ['versions', 'transaction', 'transaction_id']:
-                if isinstance(attr.property, sa.orm.RelationshipProperty):
+            if isinstance(attr.property, sa.orm.RelationshipProperty):
+                if key not in ['versions', 'transaction']:
                     if attr.property.secondary is not None:
                         setattr(self.parent, key, [])
                         for value in getattr(self, key):
@@ -162,6 +180,5 @@ class VersionClassBase(object):
                     else:
                         for value in getattr(self, key):
                             value.reify(visited_objects)
-                else:
-                    setattr(self.parent, key, getattr(self, key))
+
         return self.parent
